==> cejs-4.5.1.tgz: package/application/locale/resources/lb-LU.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2022.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"Loading...": "Lueden...",
	"Load failed": "Lueden huet net funktion\u00e9iert",
	"Loading %1%...": "Lueden %1%...",
	"Initializing...": "Initialis\u00e9ieren...",
	"Contents of [%1]": "Inhalter vu(n) [%1]",
	"Contents": "Inhalter",
	"\u2191Back to TOC": "\u2191Zr\u00e9ck op d'Inhaltsverzeechnes",
	"expand": "opklappen",
	"collapse": "zesummeklappen",
	"number": "Zuel",
	"function": "Funktioun",
	"Language": "Sprooch",
	"no change": "keng \u00c4nnerung",
	"finished": "f\u00e4erdeg",
	"no page modified,": "keng S\u00e4it ge\u00e4nnert,",
	"No changes.": "Keng \u00c4nnerungen.",
	"Abandon change": "\u00c4nnerung opginn",
	"No reason provided": "Kee Grond uginn",
	"Content is empty": "Inhalt ass eidel",
	"now": "elo",
	"several seconds ago": "virun e puer Sekonnen",
	"soon": "geschw\u00ebnn",
	"%1 hours later": "%1 Stonne m\u00e9i sp\u00e9it",
	"%1 weeks later": "%1 Woche m\u00e9i sp\u00e9it",
	"\u4e2d\u570b": "China",
	"\u65e5\u672c": "Japan",
	"\ud55c\uad6d": "Korea",
	"\u7409\u7403": "Ryukyu",
	"Vi\u1ec7t Nam": "Vietnam",
	"B\u1eafc thu\u1ed9c": "Chineesesch Dominatioun vum Vietnam",
	"India": "Indien",
	"\u1019\u103c\u1014\u103a\u1019\u102c": "Myanmar",
	"Mesopotamian": "Mesopotamesch",
	"Babylonian calendar": "Babylonesche Kalenner",
	"Babylon": "Babylonesch",
	"\u03a3\u03c0\u03ac\u03c1\u03c4\u03b7": "Sparta",
	"\u6e2c\u8a66\u7bc4\u4f8b": "BEISPILL",
	"\u4f7f\u7528\u8aaa\u660e": "KONZEPT",
	"\u554f\u984c\u56de\u5831": "FEEDBACK",
	"\u6ce8": "Notiz",
	"\u541b\u4e3b\u865f": "K\u00ebnschtlernumm",
	"\u8af1": "Richtegen Numm",
	"\u51fa\u751f": "Gebuer",
	"\u901d\u4e16": "Gestuerwen",
	"\u5728\u4f4d": "Herrschaft",
	"\u52a0\u5195": "Kr\u00e9inung",
	"\u7236\u89aa": "Papp",
	"\u6bcd\u89aa": "Mamm",
	"\u524d\u4efb": "Virg\u00e4nger",
	"\u7e7c\u4efb": "Nofollger",
	"\u661f\u671f": "Dag an der Woch",
	"Gregorian calendar": "Gregorianesche Kalenner",
	"Julian calendar": "Julianesche Kalenner",
	"\u9031\u65e5\u671f": "Dag an der Woch",
	"astronomy": "Astronomie",
	"calendar": "Kalenner",
	"\u6708\u76f8": "Moundphas",
	"lunar eclipse": "Moundfinsternis",
	"partial solar eclipse": "deelweis Sonnefinsternis",
	"\u6714": "neit Liicht",
	"\u671b": "Vollmound",
	"sunrise": "Sonnenopgank",
	"\u4f0a\u65af\u862d\u66c6": "Islamesche Kalenner",
	"Taurus": "St\u00e9ier",
	"Leo": "L\u00e9if",
	"Espa\u00f1a": "Spuenien",
	"Portugal": "Portugal",
	"Poland": "Polen",
	"Luxembourg": "L\u00ebtzebuerg",
	"Netherlands": "Holland",
	"Bavaria": "Bayern",
	"Austria": "\u00c9istr\u00e4ich",
	"Switzerland": "Schw\u00e4iz",
	"Hungary": "Ungarn",
	"Germany": "D\u00e4itschland",
	"Norway": "Norweegen",
	"Denmark": "D\u00e4nemark",
	"Great Britain": "Groussbritannien",
	"British": "Brittesch",
	"Sweden": "Schweeden",
	"Finland": "Finnland",
	"Bulgaria": "Bulgarien",
	"Soviet Union": "Sowjetunioun",
	"Serbia": "Serbien",
	"Romania": "Rum\u00e4mnien",
	"Greece": "Griicheland",
	"Turkey": "Tierkei",
	"\u5c0e\u89bd\u5217\uff1a": "Navigatioun:",
	"\u6240\u6709\u570b\u5bb6": "All L\u00e4nner",
	"\u5730\u7406\u5ea7\u6a19\uff1a": "Koordinaten:",
	"\u6642\u5340\uff1a": "Z\u00e4itzon:",
	"\u7d93\u5ea6\uff1a": "Breedegrad:",
	"\u7def\u5ea6\uff1a": "L\u00e4ngegrad:",
	"\u8457\u540d\u5730\u9ede\uff1a": "Bekannt Plazen:",
	"Options:": "Optiounen:",
	"work_data.title": "Arbechtstitel",
	"work_data.author": "Auteur",
	"work_data.last_update": "Lescht Aktualis\u00e9ierung",
	"work_data.chapter_NO": "Nummer vum Kapitel",
	"work_status-not found": "Net fonnt",
	"work_status-finished": "F\u00e4erdeg",
	"\u4f5c\u54c1\u4e0d\u5b58\u5728\u6216\u5df2\u88ab\u522a\u9664\u3002": "D'Wierk g\u00ebtt et net oder gouf gel\u00e4scht.",
	"Unknown": "Onbekannt",
	"\u4e0b\u8f09\u5716 %1": "Bild #%1 eroflueden",
	"\u5716\u7247\u7121\u5167\u5bb9\uff1a": "Keng Inhalter fonnt:",
	"\u7121\u5167\u5bb9": "Keen Inhalt",
	"\u65e5\u672c\u8a9e\u306e\u30a6\u30a7\u30d6\u30b3\u30df\u30c3\u30af": "Japanesch Web-Comics",
	"work_crawler-search_result_columns-title": "Titel",
	"work_crawler-search_result_columns-author": "Auteur",
	"\u7ae0\u7bc0\u6578\u91cf": "Zuel vun de Kapitelen",
	"work_crawler-search_result_columns-completed": "F\u00e4erdeg",
	"\u6700\u65b0\u7ae0\u7bc0": "Lescht Kapitel",
	"\u932f\u8aa4\u539f\u56e0": "Grond vum Feeler",
	"TOC.title": "Titel",
	"TOC.language": "Sprooch",
	"TOC.date": "Datum",
	"TOC.description": "Beschreiwung",
	"TOC.source": "Quell",
	"Not Yet Implemented!": "Nach net \u00ebmgesat!",
	"\u8a9e\u6cd5\u932f\u8aa4\uff01": "Syntax-Feeler!",
	"untranslated message count": "928",
	"local-language-name": "L\u00ebtzebuergesch"
},
"lb-LU");

==> cejs-4.5.2.tgz: package/application/locale/resources/lb-LU.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2022.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"untranslated message count": "1000+",
	"Espa\u00f1a": "Spuenien",
	"Load failed": "Lueden huet net funktion\u00e9iert",
	"\u5730\u7406\u5ea7\u6a19\uff1a": "Koordinaten:",
	"\u7d93\u5ea6\uff1a": "Breedegrad:",
	"\u7def\u5ea6\uff1a": "L\u00e4ngegrad:",
	"\u6642\u5340\uff1a": "Z\u00e4itzon:",
	"Loading...": "Lueden...",
	"\u5c0e\u89bd\u5217\uff1a": "Navigatioun:",
	"\u6240\u6709\u570b\u5bb6": "All L\u00e4nner",
	"\u6e2c\u8a66\u7bc4\u4f8b": "BEISPILL",
	"\u4f7f\u7528\u8aaa\u660e": "KONZEPT",
	"\u554f\u984c\u56de\u5831": "FEEDBACK",
	"Vi\u1ec7t Nam": "Vietnam",
	"Great Britain": "Groussbritannien",
	"\u541b\u4e3b\u865f": "K\u00ebnschtlernumm",
	"\u8af1": "Richtegen Numm",
	"\u51fa\u751f": "Gebuer",
	"\u901d\u4e16": "Gestuerwen",
	"\u5728\u4f4d": "Herrschaft",
	"\u52a0\u5195": "Kr\u00e9inung",
	"\u524d\u4efb": "Virg\u00e4nger",
	"\u7e7c\u4efb": "Nofollger",
	"\u7236\u89aa": "Papp",
	"\u6bcd\u89aa": "Mamm",
	"\u1019\u103c\u1014\u103a\u1019\u102c": "Myanmar",
	"Initializing...": "Initialis\u00e9ieren...",
	"Taurus": "St\u00e9ier",
	"Leo": "L\u00e9if",
	"\u6708\u76f8": "Moundphas",
	"\u661f\u671f": "Dag an der Woch",
	"\u9031\u65e5\u671f": "Dag an der Woch",
	"\u6714": "neit Liicht",
	"calendar": "Kalenner",
	"Gregorian calendar": "Gregorianesche Kalenner",
	"Julian calendar": "Julianesche Kalenner",
	"\u4f0a\u65af\u862d\u66c6": "Islamesche Kalenner",
	"\u4e2d\u570b": "China",
	"\u8457\u540d\u5730\u9ede\uff1a": "Bekannt Plazen:",
	"finished": "f\u00e4erdeg",
	"No changes.": "Keng \u00c4nnerungen.",
	"no page modified,": "keng S\u00e4it ge\u00e4nnert,",
	"astronomy": "Astronomie",
	"Loading %1%...": "Lueden %1%...",
	"\u671b": "Vollmound",
	"partial solar eclipse": "deelweis Sonnefinsternis",
	"lunar eclipse": "Moundfinsternis",
	"sunrise": "Sonnenopgank",
	"Not Yet Implemented!": "Nach net \u00ebmgesat!",
	"Language": "Sprooch",
	"No content": "Keen Inhalt",
	"Content is empty": "Inhalt ass eidel",
	"Abandon change": "\u00c4nnerung opginn",
	"No reason provided": "Kee Grond uginn",
	"Does not exist": "G\u00ebtt et net",
	"no change": "keng \u00c4nnerung",
	"Edit %1": "%1 \u00e4nneren",
	"Missing page": "S\u00e4it feelt",
	"\u7121\u9801\u9762\u91cd\u5b9a\u5411\u81f3\u672c\u9801": "Keng S\u00e4it leed virun op d\u00ebs S\u00e4it",
	"function": "Funktioun",
	"number": "Zuel",
	"\u4e0b\u8f09\u5716 %1": "Bild #%1 eroflueden",
	"\u5716\u7247\u7121\u5167\u5bb9\uff1a": "Bild ouni Inhalt:",
	"work_data.chapter_NO": "Nummer vum Kapitel",
	"\u4f5c\u54c1\u4e0d\u5b58\u5728\u6216\u5df2\u88ab\u522a\u9664\u3002": "D'Wierk g\u00ebtt et net oder gouf gel\u00e4scht.",
	"Unknown": "Onbekannt",
	"work_data.author": "Auteur",
	"work_data.last_update": "Lescht Aktualis\u00e9ierung",
	"work_data.title": "Arbechtstitel",
	"work_status-finished": "F\u00e4erdeg",
	"work_status-not found": "Net fonnt",
	"TOC.date": "Datum",
	"TOC.description": "Beschreiwung",
	"TOC.language": "Sprooch",
	"TOC.source": "Quell",
	"TOC.title": "Titel",
	"Contents": "Inhalter",
	"Poland": "Polen",
	"Portugal": "Portugal",
	"Luxembourg": "L\u00ebtzebuerg",
	"Netherlands": "Holland",
	"Bavaria": "Bayern",
	"Austria": "\u00c9istr\u00e4ich",
	"Switzerland": "Schw\u00e4iz",
	"Hungary": "Ungarn",
	"Germany": "D\u00e4itschland",
	"Norway": "Norweegen",
	"Denmark": "D\u00e4nemark",
	"Sweden": "Schweeden",
	"Finland": "Finnland",
	"Bulgaria": "Bulgarien",
	"Soviet Union": "Sowjetunioun",
	"Serbia": "Serbien",
	"Romania": "Rum\u00e4mnien",
	"Greece": "Griicheland",
	"T\u00fcrkiye": "Tierkei",
	"now": "elo",
	"several seconds ago": "virun e puer Sekonnen",
	"soon": "geschw\u00ebnn",
	"%1 {{PLURAL:%1|second|seconds}} ago": "{{PLURAL:%1|virun 1 Sekonn|viru(n) %1 Sekonnen}}",
	"%1 {{PLURAL:%1|minute|minutes}} later": "{{PLURAL:%1|eng Minutt|%1 Minutte}} m\u00e9i sp\u00e9it",
	"%1 {{PLURAL:%1|hour|hours}} later": "%1 {{PLURAL:%1|Stonn|Stonne}} m\u00e9i sp\u00e9it",
	"%1 {PLURAL:%1|week|weeks}} later": "%1 {{PLURAL:%1|Woch|Woche}} m\u00e9i sp\u00e9it",
	"\u6ce8": "Notiz",
	"\u7409\u7403": "Ryukyu",
	"\u65e5\u672c": "Japan",
	"\ud55c\uad6d": "Korea",
	"B\u1eafc thu\u1ed9c": "Chineesesch Dominatioun vum Vietnam",
	"India": "Indien",
	"Mesopotamian": "Mesopotamesch",
	"Babylon": "Babylonesch",
	"Babylonian calendar": "Babylonesche Kalenner",
	"\u03a3\u03c0\u03ac\u03c1\u03c4\u03b7": "Sparta",
	"British": "Brittesch",
	"\u8a9e\u6cd5\u932f\u8aa4\uff01": "Syntax-Feeler!",
	"\u2191Back to TOC": "\u2191Zr\u00e9ck op d'Inhaltsverzeechnes",
	"Contents of [%1]": "Inhalter vu(n) [%1]",
	"expand": "opklappen",
	"collapse": "zesummeklappen",
	"Namespaces: %1.": "Nummr\u00e4im: %1.",
	"No title found for %1.": "Keen Titel fonnt fir %1.",
	"\u5dee\u7570\u6975\u5927": "GANZ VERSCHIDDEN",
	"\u8acb\u5e6b\u5fd9\u6aa2\u6838\u6b64\u6b21\u7de8\u8f2f\u3002": "H\u00eblleft wgl. fir d\u00ebs \u00c4nnerung nozekucken.",
	"work_crawler-search_result_columns-title": "Titel",
	"work_crawler-search_result_columns-author": "Auteur",
	"\u7ae0\u7bc0\u6578\u91cf": "Zuel vun de Kapitelen",
	"work_crawler-search_result_columns-completed": "F\u00e4erdeg",
	"\u6700\u65b0\u7ae0\u7bc0": "Lescht Kapitel",
	"\u932f\u8aa4\u539f\u56e0": "Grond vum Feeler",
	"\u65e5\u672c\u8a9e\u306e\u30a6\u30a7\u30d6\u30b3\u30df\u30c3\u30af": "Japanesch Web-Comics",
	"local-language-name": "L\u00ebtzebuergesch",
	"Options:": "Optiounen:"
},
"lb-LU");
